/* easyzlib.h header

  easyzlib release 1.0
  Copyright (C) 2008 First Objective Software, Inc. All rights reserved
  This entire notice must be retained in this source code
  Redistributing this source code requires written permission
  This software is provided "as is", with no warranty.
  Latest fixes enhancements and documentation at www.firstobject.com
*/

#ifndef _EASYZLIB_H
#define _EASYZLIB_H

/* Return codes */
#define EZ_STREAM_ERROR  (-2)
#define EZ_DATA_ERROR    (-3)
#define EZ_MEM_ERROR     (-4)
#define EZ_BUF_ERROR     (-5)

/* Calculate maximum compressed length from uncompressed length */
#define EZ_COMPRESSMAXDESTLENGTH(n) (n+(((n)/1000)+1)+12)

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */

int ezcompress( unsigned char* pDest, long* pnDestLen, const unsigned char* pSrc, long nSrcLen, int level, int windowBits, int memLevel, int strategy);
int ezuncompress( unsigned char* pDest, long* pnDestLen, const unsigned char* pSrc, long nSrcLen, int windowBits );

#ifdef __cplusplus
}

struct ezbuffer
{
	ezbuffer() { Init(); };
	ezbuffer( int n ) { Init(); Alloc(n); };
	~ezbuffer() { Release(); };
	unsigned char* Alloc( int n ) { if (nSize<n) {Release(); pBuf=new unsigned char[n]; nSize = n;} nLen=n; return pBuf; };
	void Release() { if (pBuf) { delete[] pBuf; Init(); } };
	unsigned char* pBuf;
	long nLen; /* data length */
	long nSize; /* bytes allocated */
	
private:
	void Init() { pBuf = 0; nSize=0; nLen=0; };
};

#define EZ_CHECKLENGTH 8192

int ezcompress( ezbuffer& bufDest, const ezbuffer& bufSrc, int level, int windowBits, int memLevel, int strategy)
{
	if ( bufDest.nLen == 0 )
		bufDest.Alloc( EZ_CHECKLENGTH );
	int nErr = ezcompress( bufDest.pBuf, &bufDest.nLen, bufSrc.pBuf, bufSrc.nLen, level, windowBits, memLevel, strategy);
	if ( nErr == EZ_BUF_ERROR )
	{
		bufDest.Alloc( bufDest.nLen );
		nErr = ezcompress( bufDest.pBuf, &bufDest.nLen, bufSrc.pBuf, bufSrc.nLen, level, windowBits, memLevel, strategy);
	}
	return nErr;
};

int ezuncompress( ezbuffer& bufDest, const ezbuffer& bufSrc, int windowBits)
{
	if ( bufDest.nLen == 0 )
		bufDest.Alloc( EZ_CHECKLENGTH );
	int nErr = ezuncompress( bufDest.pBuf, &bufDest.nLen, bufSrc.pBuf, bufSrc.nLen, windowBits);
	if ( nErr == EZ_BUF_ERROR )
	{
		bufDest.Alloc( bufDest.nLen );
		nErr = ezuncompress( bufDest.pBuf, &bufDest.nLen, bufSrc.pBuf, bufSrc.nLen, windowBits);
	}
	return nErr;
};


#endif /* __cplusplus */

#endif /* _EASYZLIB_H */
